# Getting Started
`citrine-python` is the Python library for the Citrine Platform. To get started, first install `citrine-python`:

```bash
pip install citrine
```

Detailed instructions on installation and usage can be found in the complete [citrine-python docs](https://citrineinformatics.github.io/citrine-python/index.html)

# Contributing

To find detailed contributing guidelines, please see the [contributing documentation](https://github.com/CitrineInformatics/citrine-python/blob/master/CONTRIBUTING.md).


